
/*-- E4P2 --------------------------------------------------------------*/
/*									*/
/*	Tanescu A. Horatiu						*/
/*	clasa a XI-a B							*/
/*	Liceul Teoretic "E.Gojdu" Oradea				*/
/*									*/
/*------------------------------------------- alpha@lego.soroscj.ro ----*/

#include <conio.h>
#include <stdio.h>
#include <stdlib.h>

const char* INFILENAME  = "input";
const char* OUTFILENAME = "output";
const TESTLINE_LEN      = 100;

/* Definition of class TCoordinates
 */

class TCoordinates
{
  int n;
  int rows[6];
  int origrows[6];
  int columns[6];
  static char* names[];
  static char* testlineformat;

public:
  TCoordinates(const char* cline);
  int isValid(void);
  char* name(void);
  void writeSolution(FILE* f);

private:
  int isAValidTriangle(void);
  int isAValidParallelogram(void);
  int isAValidHexagon(void);
};

/* Definition of class TInputFile
 */

class TInputFile
{
  FILE* f;
  char line[TESTLINE_LEN];

public:
  TInputFile(const char* fname);
  int Next(void)    { return (fgets(line, TESTLINE_LEN, f) != 0); }
  char* Line(void)  { return (line); }
  ~TInputFile(void) { fclose(f); }
};

/* Implementation of class TCoordinates
 */

char* near TCoordinates::names[] = {
  "triunghi", "paralelogram", "hexagon", "figura necunoscuta" };

char* near TCoordinates::testlineformat = "%d %d %d %d %d %d";

int IntSort(const void *a, const void *b) { return(*(int*)a - *(int*)b); }

TCoordinates::TCoordinates(const char* cline)
{
  if ((n = sscanf(cline, testlineformat, rows, rows + 1, rows + 2, rows + 3,
		  rows + 4, rows + 5)) <= 0) return;

  int i;
  for (i = 0; i < n; i++) *(origrows + i) = *(rows + i);

  qsort(rows, n, sizeof(int), IntSort);

  int j, k;
  for (i = 0; i < n; i++)
  {
    for (j = 1, k = 1; *(rows + i) >= j + k; j += k++);
    *(columns + i) = *(rows + i) - j;
    *(rows + i) = k;
  }
}

int TCoordinates::isValid(void)
{
  switch (n) {
    case  3: return isAValidTriangle();
    case  4: return isAValidParallelogram();
    case  6: return isAValidHexagon();
    default: return 0;
  }
}

char* TCoordinates::name(void)
{
  switch (n) {
    case  3: return *(names);
    case  4: return *(names + 1);
    case  6: return *(names + 2);
    default: return *(names + 3);
  }
}

void TCoordinates::writeSolution(FILE* f)
{
  for (int i = 0; i < n; i++) fprintf(f, "%d ", *(origrows + i));

  if (!isValid()) fprintf(f, "nu sunt varfurile unei figuri acceptabile");
  else
    fprintf(f, "sunt varfurile unui %s", name());

  fputs("\n", f);
}

int TCoordinates::isAValidTriangle(void)
{
  if (*rows == *(rows + 1))
  {
    int column = *(columns + 1) - *columns;
    return (column > 0 && *(columns + 2) == *(columns + 1) &&
	    *(rows + 2) == *rows + column);
  }
  else
  {
    int row = *(rows + 1) - *rows;
    return (row > 0 && *columns == *(columns + 1) && *(rows + 2) == *(rows + 1)
	   && *(columns + 2) == *(columns + 1) + row);
  }
}

int TCoordinates::isAValidParallelogram(void)
{
  if (*rows == *(rows + 1))
  {
    int column = *(columns + 1) - *columns;
    return (column > 0 && *(rows + 2) == *(rows + 3) &&
	    *(columns + 3) - *(columns + 2) == column &&
	    *(rows + 2) - *rows == column &&
	    (*(columns + 2) == *columns || *(columns + 2) == *(columns + 1)));
   }
   else
   {
     int row = *(rows + 1) - *rows;
     return (row > 0 && *columns == *(columns + 1) &&
	     *(columns + 2) == *(columns + 3) &&
	     *(rows + 1) == *(rows + 2) &&
	     *(rows + 3) - *(rows + 2) == row &&
	     *(columns + 2) - *(columns + 1) == row);
   }
}

int TCoordinates::isAValidHexagon(void)
{
  int column = *(columns + 1) - *columns;
  return (
    column > 0 &&
    *rows       == *(rows + 1)          && *(columns + 2) == *columns &&
    *(rows + 2) == *rows + column       && *(columns + 3) == *(columns + 1) + column &&
    *(rows + 3) == *(rows + 2)          && *(columns + 4) == *(columns + 1) &&
    *(rows + 4) == *(rows + 2) + column && *(columns + 5) == *(columns + 3) &&
    *(rows + 5) == *(rows + 4)
  );
}

/* Implementation of class TInputFile
 */

TInputFile::TInputFile(const char* fname)
{
  if ((f = fopen(fname, "rt")) == NULL) {
    fprintf(stderr, "Cannot open input file.\n"); exit(1);
  }
  clrscr();
  cprintf("Input file is %s\r\n\r\n", fname);
}

/* Main function
 */

int main(void)
{
  FILE* outfile = fopen(OUTFILENAME, "w+");

  TInputFile InputFile(INFILENAME);
  while (InputFile.Next())
  {
    TCoordinates coord(InputFile.Line());
    coord.writeSolution(outfile);
  }

  fclose(outfile);
  return 0;
}
